@@ -1,46 +1,42 @@
-import warnings
-from typing import Optional
+from typing import Any
 
 from faststream.security import (
+    SASLGSSAPI,
     BaseSecurity,
+    SASLOAuthBearer,
     SASLPlaintext,
     SASLScram256,
     SASLScram512,
-    ssl_not_set_error_msg,
 )
-from faststream.types import AnyDict
 
 
-def parse_security(security: Optional[BaseSecurity]) -> AnyDict:
+def parse_security(security: BaseSecurity | None) -> dict[str, Any]:
     if security is None:
         return {}
-    elif type(security) == BaseSecurity:
-        return _parse_base_security(security)
-    elif type(security) == SASLPlaintext:
+    if isinstance(security, SASLPlaintext):
         return _parse_sasl_plaintext(security)
-    elif type(security) == SASLScram256:
+    if isinstance(security, SASLScram256):
         return _parse_sasl_scram256(security)
-    elif type(security) == SASLScram512:
+    if isinstance(security, SASLScram512):
         return _parse_sasl_scram512(security)
-    else:
-        raise NotImplementedError(f"KafkaBroker does not support {type(security)}")
+    if isinstance(security, SASLOAuthBearer):
+        return _parse_sasl_oauthbearer(security)
+    if isinstance(security, SASLGSSAPI):
+        return _parse_sasl_gssapi(security)
+    if isinstance(security, BaseSecurity):
+        return _parse_base_security(security)
+    msg = f"KafkaBroker does not support `{type(security)}`."
+    raise NotImplementedError(msg)
 
 
-def _parse_base_security(security: BaseSecurity) -> AnyDict:
+def _parse_base_security(security: BaseSecurity) -> dict[str, Any]:
     return {
         "security_protocol": "SSL" if security.use_ssl else "PLAINTEXT",
         "ssl_context": security.ssl_context,
     }
 
 
-def _parse_sasl_plaintext(security: SASLPlaintext) -> AnyDict:
-    if security.use_ssl is None:
-        warnings.warn(
-            message=ssl_not_set_error_msg,
-            category=RuntimeWarning,
-            stacklevel=1,
-        )
-
+def _parse_sasl_plaintext(security: SASLPlaintext) -> dict[str, Any]:
     return {
         "security_protocol": "SASL_SSL" if security.use_ssl else "SASL_PLAINTEXT",
         "ssl_context": security.ssl_context,
@@ -50,7 +46,7 @@ def _parse_sasl_plaintext(security: SASLPlaintext) -> AnyDict:
     }
 
 
-def _parse_sasl_scram256(security: SASLScram256) -> AnyDict:
+def _parse_sasl_scram256(security: SASLScram256) -> dict[str, Any]:
     return {
         "security_protocol": "SASL_SSL" if security.use_ssl else "SASL_PLAINTEXT",
         "ssl_context": security.ssl_context,
@@ -60,7 +56,7 @@ def _parse_sasl_scram256(security: SASLScram256) -> AnyDict:
     }
 
 
-def _parse_sasl_scram512(security: SASLScram512) -> AnyDict:
+def _parse_sasl_scram512(security: SASLScram512) -> dict[str, Any]:
     return {
         "security_protocol": "SASL_SSL" if security.use_ssl else "SASL_PLAINTEXT",
         "ssl_context": security.ssl_context,
@@ -68,3 +64,19 @@ def _parse_sasl_scram512(security: SASLScram512) -> AnyDict:
         "sasl_plain_username": security.username,
         "sasl_plain_password": security.password,
     }
+
+
+def _parse_sasl_oauthbearer(security: SASLOAuthBearer) -> dict[str, Any]:
+    return {
+        "security_protocol": "SASL_SSL" if security.use_ssl else "SASL_PLAINTEXT",
+        "ssl_context": security.ssl_context,
+        "sasl_mechanism": "OAUTHBEARER",
+    }
+
+
+def _parse_sasl_gssapi(security: SASLGSSAPI) -> dict[str, Any]:
+    return {
+        "security_protocol": "SASL_SSL" if security.use_ssl else "SASL_PLAINTEXT",
+        "ssl_context": security.ssl_context,
+        "sasl_mechanism": "GSSAPI",
+    }
