@@ -1,23 +1,25 @@
-from typing import Any, Optional
+from typing import Any
 
 from redis.asyncio.connection import Connection
 
 from faststream.security import BaseSecurity, SASLPlaintext
-from faststream.types import AnyDict
 
 
-def parse_security(security: Optional[BaseSecurity]) -> AnyDict:
+def parse_security(security: BaseSecurity | None) -> dict[str, Any]:
     if security is None:
         return {}
-    elif isinstance(security, SASLPlaintext):
+
+    if isinstance(security, SASLPlaintext):
         return _parse_sasl_plaintext(security)
-    elif isinstance(security, BaseSecurity):
+
+    if isinstance(security, BaseSecurity):
         return _parse_base_security(security)
-    else:
-        raise NotImplementedError(f"RedisBroker does not support {type(security)}")
+
+    msg = f"RedisBroker does not support {type(security)}"
+    raise NotImplementedError(msg)
 
 
-def _parse_base_security(security: BaseSecurity) -> AnyDict:
+def _parse_base_security(security: BaseSecurity) -> dict[str, Any]:
     if security.use_ssl:
 
         class SSLConnection(Connection):
@@ -25,21 +27,21 @@ def _parse_base_security(security: BaseSecurity) -> AnyDict:
                 self,
                 _security: BaseSecurity = security,
                 **kwargs: Any,
-            ):
+            ) -> None:
                 self._security = _security
                 super().__init__(**kwargs)
 
             def _connection_arguments(self) -> Any:
-                kwargs = super()._connection_arguments()  # type: ignore
-                kwargs["ssl"] = self._security.ssl_context
-                return kwargs
+                return {
+                    **super()._connection_arguments(),  # type: ignore[misc]
+                    "ssl": self._security.ssl_context,
+                }
 
         return {"connection_class": SSLConnection}
-    else:
-        return {}
+    return {}
 
 
-def _parse_sasl_plaintext(security: SASLPlaintext) -> AnyDict:
+def _parse_sasl_plaintext(security: SASLPlaintext) -> dict[str, Any]:
     return {
         **_parse_base_security(security),
         "username": security.username,
